==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/UserAttributesFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link UserAttributes}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class UserAttributesFieldAttributes extends AbstractBeanAttributesDefinition{

    /** attributeKey (Database column: ATTRIBUTE_KEY) */
    static public AttributeDefinition attributeKey =
        new AttributeDefinition("attributeKey")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_ATTRIBUTES")
                .setDatabaseId("ATTRIBUTE_KEY")
                .setMandatory(true)
                .setMaxSize(200)
                .setType(String.class);

    /** attributeValue (Database column: ATTRIBUTE_VALUE) */
    static public AttributeDefinition attributeValue =
        new AttributeDefinition("attributeValue")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_ATTRIBUTES")
                .setDatabaseId("ATTRIBUTE_VALUE")
                .setMandatory(true)
                .setMaxSize(2000)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_ATTRIBUTES")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** users (Database column: USERID) */
    static public AttributeDefinition users =
        new AttributeDefinition("users")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_ATTRIBUTES")
                .setDatabaseId("USERID")
                .setMandatory(true)
                .setMaxSize(200)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Users.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Users.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(attributeKey.getName(),attributeKey);
        map.put(attributeValue.getName(),attributeValue);
        map.put(id.getName(),id);
        map.put(users.getName(),users);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/UserAttributesFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link UserAttributes}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class UserAttributesFieldAttributes extends AbstractBeanAttributesDefinition{

    /** attributeKey (Database column: ATTRIBUTE_KEY) */
    static public AttributeDefinition attributeKey =
        new AttributeDefinition("attributeKey")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_ATTRIBUTES")
                .setDatabaseId("ATTRIBUTE_KEY")
                .setMandatory(true)
                .setMaxSize(200)
                .setType(String.class);

    /** attributeValue (Database column: ATTRIBUTE_VALUE) */
    static public AttributeDefinition attributeValue =
        new AttributeDefinition("attributeValue")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_ATTRIBUTES")
                .setDatabaseId("ATTRIBUTE_VALUE")
                .setMandatory(false)
                .setMaxSize(2000)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_ATTRIBUTES")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(9)
                .setType(Long.class);

    /** users (Database column: USERID) */
    static public AttributeDefinition users =
        new AttributeDefinition("users")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("USER_ATTRIBUTES")
                .setDatabaseId("USERID")
                .setMandatory(true)
                .setMaxSize(200)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Users.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Users.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(attributeKey.getName(),attributeKey);
        map.put(attributeValue.getName(),attributeValue);
        map.put(id.getName(),id);
        map.put(users.getName(),users);

        return map;
    }
}
